Known issues
------------

.. _git_cred_windows:

Authentication problems with BitBucket
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Git authentication works so so on Windows. Try installing the new the
new `Git Credential Manager for
Windows <https://github.com/Microsoft/Git-Credential-Manager-for-Windows/releases/latest>`__
and try to the step that failed again..
